/*
 * Copyright 2025, Steinberg Media Technologies GmbH, All Rights Reserved
 * Copyright 2025 Linux Studio Plugins Project <lsp.plugin@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _3RD_PARTY_STEINBERG_VST3_GUI_H_
#define _3RD_PARTY_STEINBERG_VST3_GUI_H_

#include <steinberg/vst3/version.h>

#include <steinberg/vst3/gui/ViewRect.h>
#include <steinberg/vst3/gui/IPlugFrame.h>
#include <steinberg/vst3/gui/IPlugView.h>
#include <steinberg/vst3/gui/IPlugViewContentScaleSupport.h>
#include <steinberg/vst3/gui/IEventHandler.h>
#include <steinberg/vst3/gui/ITimerHandler.h>
#include <steinberg/vst3/gui/IRunLoop.h>
#include <steinberg/vst3/gui/IWaylandHost.h>
#include <steinberg/vst3/gui/IWaylandFrame.h>

#endif /* _3RD_PARTY_STEINBERG_VST3_VST_H_ */
